Exception: Kuu::CliNotFound

Inherits:
Error
  • Object
show all
Defined in:
lib/kuu.rb

Instance Method Summary collapse

Constructor Details

#initialize(msg = "kuu-cli not found on PATH. Install it from https://github.com/kawaz/kuu-cli (this early version of the kuu gem delegates to the reference CLI)") ⇒ CliNotFound

Returns a new instance of CliNotFound.



12
13
14
# File 'lib/kuu.rb', line 12

def initialize(msg = "kuu-cli not found on PATH. Install it from https://github.com/kawaz/kuu-cli (this early version of the kuu gem delegates to the reference CLI)")
  super
end