Exception: Kuu::CliNotFound
Instance Method Summary collapse
-
#initialize(msg = "kuu-cli not found on PATH. Install it from https://github.com/kawaz/kuu-cli (this early version of the kuu gem delegates to the reference CLI)") ⇒ CliNotFound
constructor
A new instance of CliNotFound.
Constructor Details
#initialize(msg = "kuu-cli not found on PATH. Install it from https://github.com/kawaz/kuu-cli (this early version of the kuu gem delegates to the reference CLI)") ⇒ CliNotFound
Returns a new instance of CliNotFound.
12 13 14 |
# File 'lib/kuu.rb', line 12 def initialize(msg = "kuu-cli not found on PATH. Install it from https://github.com/kawaz/kuu-cli (this early version of the kuu gem delegates to the reference CLI)") super end |